netapp_ontap.models.storage_pool_capacity API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_pool_capacity`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StoragePoolCapacitySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StoragePoolCapacity object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `disk_count: Size GET POST PATCH`

    The number of disks in the storage pool.

  `disks: List[StoragePoolDisk] GET POST PATCH`

    Properties of each disk used in the shared storage pool.

  `remaining: Size GET`

    Remaining usable capacity in the flash pool, in bytes.

  `spare_allocation_units: List[StoragePoolSpareAllocationUnit] GET POST PATCH`

    Properties of spare allocation units.

  `total: Size GET`

    Total size of the flash pool, in bytes.

  `used_allocation_units: List[StoragePoolUsedAllocationUnit] GET`

    Information about the storage pool allocation units participating in the cache tier of an aggregate.